=======
Credits
=======

Development Lead
----------------

* Paul McLanahan <pmac@mozilla.com>

Contributors
------------

* Steve Jalim <opensource@stevejalim.mozmail.com>
* Michael Manganiello - https://github.com/adamantike


